summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGStylableImpl.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /ksvg/impl/SVGStylableImpl.cc
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'ksvg/impl/SVGStylableImpl.cc')
-rw-r--r--ksvg/impl/SVGStylableImpl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksvg/impl/SVGStylableImpl.cc b/ksvg/impl/SVGStylableImpl.cc
index 9471c562..d1019ff8 100644
--- a/ksvg/impl/SVGStylableImpl.cc
+++ b/ksvg/impl/SVGStylableImpl.cc
@@ -711,7 +711,7 @@ float SVGStylableImpl::fontSizeForText(const TQString &value)
text-anchor SVGStylableImpl::TextAnchor DontDelete|ReadOnly
direction SVGStylableImpl::Direction DontDelete|ReadOnly
writing-mode SVGStylableImpl::WritingMode DontDelete|ReadOnly
- unicode-bidi SVGStylableImpl::UnicodeBidi DontDelete|ReadOnly
+ tqunicode-bidi SVGStylableImpl::UnicodeBidi DontDelete|ReadOnly
opacity SVGStylableImpl::Opacity DontDelete|ReadOnly
fill-opacity SVGStylableImpl::FillOpacity DontDelete|ReadOnly
stroke-opacity SVGStylableImpl::StrokeOpacity DontDelete|ReadOnly
@@ -1006,7 +1006,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
break;
case Direction:
m_flags |= SVG_STYLE_FLAG_TEXT_DIRECTION;
// Spec: direction is only processed when unicode-bidi
// is set to bidi-override or embedded
if(m_textUnicodeBidi == OVERRIDE ||
m_textUnicodeBidi == EMBED ||
@@ -1276,16 +1276,16 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
if(redraw)
{
- SVGShapeImpl *shape = dynamic_cast<SVGShapeImpl *>(m_object);
+ SVGShapeImpl *tqshape = dynamic_cast<SVGShapeImpl *>(m_object);
if(inherit)
processStyle();
- if(shape && shape->item())
+ if(tqshape && tqshape->item())
{
if(update > -1)
- shape->item()->update(static_cast<CanvasItemUpdate>(update));
+ tqshape->item()->update(static_cast<CanvasItemUpdate>(update));
else if(m_object)
- m_object->ownerDoc()->canvas()->invalidate(shape->item(), false);
+ m_object->ownerDoc()->canvas()->tqinvalidate(tqshape->item(), false);
}
}
}
@@ -1006,7 +1006,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
case Direction:
m_flags |= SVG_STYLE_FLAG_TEXT_DIRECTION;
- // Spec: direction is only processed when unicode-bidi
+ // Spec: direction is only processed when tqunicode-bidi
// is set to bidi-override or embedded
if(m_textUnicodeBidi == OVERRIDE ||